@@ -3,6 +3,7 @@ import datetime
 import pytz
 import time
 import random
+from python_grains.locks import Lock
 
 DEFAULT_DOMAIN = None
 DEFAULT_REDIS_CLIENT = None
@@ -121,6 +122,14 @@ class StitchPool(object):
 
         return [cls.from_key(stitchpool_key.decode()) for stitchpool_key, timestamp in expired_stitchpools]
 
+    def lock(self, ttl):
+        return Lock('sp' + str(self.user_id), self.redis_client, ttl=ttl * 1000)
+
+    def delete_from_cache(self):
+        self.redis_client.delete(self.key)
+        self.redis_client.zrem(self.all_stitchpools_key, self.key)
+
+
     def to_db(self):
 
         # first call complement_from_db!
@@ -268,6 +277,7 @@ class Stitch(object):
 
     def delete_from_cache(self):
         self.redis_client.delete(self.key)
+        self.redis_client.zrem(self.all_stitches_key, self.key)
 
     def offload(self):
         self.get(force_db=True)
@@ -281,6 +291,9 @@ class Stitch(object):
             args=self.user_ids
         )
 
+    def lock(self, ttl):
+        return Lock('st' + str(self.value), self.redis_client, ttl=ttl * 1000)
+
     def to_cache(self):
         pipe = self.redis_client.pipeline()
         pipe.zadd(self.key, self.user_ids_with_ts)
